@@ -49,10 +49,7 @@ public:
     ~KAddressBookPlugin();
 
     bool isRunningStandalone() const override;
-    int weight() const override
-    {
-        return 300;
-    }
+    int weight() const override;
 
     QStringList invisibleToolbarActions() const override;
     void shortcutChanged() override;
@@ -60,12 +57,11 @@ public:
 protected:
     KParts::ReadOnlyPart *createPart() override;
 
-private Q_SLOTS:
+private:
     void slotNewContact();
     void slotNewContactGroup();
 
-private:
-    KontactInterface::UniqueAppWatcher *mUniqueAppWatcher;
+    KontactInterface::UniqueAppWatcher *mUniqueAppWatcher = nullptr;
 };
 
 #endif
