@@ -35,10 +35,9 @@ public:
     void load() override;
     void save() override;
     void defaults() override;
-private Q_SLOTS:
-    void slotConfigChanged();
 private:
-    PimCommon::ConfigurePluginsWidget *mConfigurePluginWidget;
+    void slotConfigChanged();
+    PimCommon::ConfigurePluginsWidget *mConfigurePluginWidget = nullptr;
 };
 }
 #endif // KCMKaddressbookPluginsConfig_H
