@@ -29,10 +29,10 @@ public:
     explicit KAddressBookConfigPluginListWidget(QWidget *parent = nullptr);
     ~KAddressBookConfigPluginListWidget();
 
-    void save() Q_DECL_OVERRIDE;
-    void doLoadFromGlobalSettings() Q_DECL_OVERRIDE;
-    void doResetToDefaultsOther() Q_DECL_OVERRIDE;
-    void initialize() Q_DECL_OVERRIDE;
+    void save() override;
+    void doLoadFromGlobalSettings() override;
+    void doResetToDefaultsOther() override;
+    void initialize() override;
 private:
     void slotConfigureClicked(const QString &configureGroupName, const QString &identifier);
     QList<PluginItem *> mPluginGenericItems;
