@@ -23,8 +23,7 @@
 
 #include <KContacts/Addressee>
 #include "kaddressbookdomain_export.h"
-namespace Domain
-{
+namespace Domain {
 class KADDRESSBOOKDOMAIN_EXPORT Contact
 {
 public:
