@@ -17,36 +17,38 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #include "manageshowcollectionproperties.h"
 #include "mainwidget.h"
 #include "kaddressbook_debug.h"
 #include <PimCommonAkonadi/CollectionAclPage>
 
 #include <AkonadiWidgets/CollectionPropertiesDialog>
+#include <AkonadiWidgets/CollectionMaintenancePage>
 #include <AkonadiCore/CollectionAttributesSynchronizationJob>
 #include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/CollectionFetchScope>
 
 #include <KLocalizedString>
 
 ManageShowCollectionProperties::ManageShowCollectionProperties(MainWidget *mainWidget, QObject *parent)
-    : QObject(parent),
-      mMainWidget(mainWidget)
+    : QObject(parent)
+    , mMainWidget(mainWidget)
 {
     static bool pageRegistered = false;
 
     if (!pageRegistered) {
         Akonadi::CollectionPropertiesDialog::registerPage(new PimCommon::CollectionAclPageFactory);
+        Akonadi::CollectionPropertiesDialog::registerPage(new Akonadi::CollectionMaintenancePageFactory);
         pageRegistered = true;
     }
     mPages = QStringList() << QStringLiteral("Akonadi::CollectionGeneralPropertiesPage")
                            << QStringLiteral("Akonadi::CachePolicyPage")
-                           << QStringLiteral("PimCommon::CollectionAclPage");
+                           << QStringLiteral("PimCommon::CollectionAclPage")
+                           << QStringLiteral("Akonadi::CollectionMaintenancePage");
 }
 
 ManageShowCollectionProperties::~ManageShowCollectionProperties()
 {
-
 }
 
 void ManageShowCollectionProperties::showCollectionProperties()
@@ -78,7 +80,8 @@ void ManageShowCollectionProperties::slotCollectionPropertiesContinued(KJob *job
         }
     }
     Akonadi::CollectionFetchJob *fetch = new Akonadi::CollectionFetchJob(mMainWidget->currentAddressBook(),
-            Akonadi::CollectionFetchJob::Base);
+                                                                         Akonadi::CollectionFetchJob::Base);
+    fetch->fetchScope().setIncludeStatistics(true);
     connect(fetch, &KJob::result,
             this, &ManageShowCollectionProperties::slotCollectionPropertiesFinished);
 }
