@@ -67,13 +67,11 @@ public:
 protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
-private Q_SLOTS:
-    void adaptHeaderView();
-
 private:
-    Akonadi::ContactsTreeModel *mModel;
+    void adaptHeaderView();
+    Akonadi::ContactsTreeModel *mModel = nullptr;
     Akonadi::ContactsTreeModel::Columns mColumns;
-    QWidget *mWidget;
+    QWidget *mWidget = nullptr;
 };
 
 #endif
