@@ -22,31 +22,10 @@
 #include "kaddressbook_debug.h"
 #include "mainwidget.h"
 
-#include <KActionCollection>
-
 #include <pimcommon/genericplugin.h>
 
-class KAddressBookPluginInterfacePrivate
-{
-public:
-    KAddressBookPluginInterfacePrivate()
-        : kaddressBookPluginInterface(new KAddressBookPluginInterface)
-    {
-    }
-
-    ~KAddressBookPluginInterfacePrivate()
-    {
-        delete kaddressBookPluginInterface;
-    }
-
-    KAddressBookPluginInterface *kaddressBookPluginInterface;
-};
-
-Q_GLOBAL_STATIC(KAddressBookPluginInterfacePrivate, sInstance)
-
 KAddressBookPluginInterface::KAddressBookPluginInterface(QObject *parent)
     : PimCommon::PluginInterface(parent)
-    , mMainWidget(nullptr)
 {
     setPluginName(QStringLiteral("kaddressbook"));
     setServiceTypeName(QStringLiteral("KAddressBook/MainViewPlugin"));
@@ -58,7 +37,8 @@ KAddressBookPluginInterface::~KAddressBookPluginInterface()
 
 KAddressBookPluginInterface *KAddressBookPluginInterface::self()
 {
-    return sInstance->kaddressBookPluginInterface;
+    static KAddressBookPluginInterface s_self;
+    return &s_self;
 }
 
 void KAddressBookPluginInterface::initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *abstractInterface)
