@@ -21,7 +21,6 @@
 #define KADDRESSBOOKPLUGININTERFACE_H
 
 #include <QObject>
-#include <QVector>
 
 #include <PimCommonAkonadi/GenericPluginInterface>
 #include <pimcommonakonadi/plugininterface.h>
@@ -38,7 +37,7 @@ public:
     void initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *interface) override;
     static KAddressBookPluginInterface *self();
 private:
-    MainWidget *mMainWidget;
+    MainWidget *mMainWidget = nullptr;
 };
 
 #endif // KADDRESSBOOKPLUGININTERFACE_H
