@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ public:
 
     void print(const KContacts::Addressee::List &, PrintProgress *) override;
 private:
-    KAddressBookGrantlee::GrantleePrint *mGrantleePrint;
+    KAddressBookGrantlee::GrantleePrint *mGrantleePrint = nullptr;
 };
 
 class GrantleeStyleFactory : public PrintStyleFactory
