@@ -40,8 +40,6 @@ using namespace KABPrinting;
 
 static QString contactsToHtml(const KContacts::Addressee::List &contacts)
 {
-    QString content;
-
     KAddressBookImportExport::KAddressBookImportExportContactFields::Fields leftFields, rightFields;
     KAddressBookImportExport::KAddressBookImportExportContactFields::Fields allFields = KAddressBookImportExport::KAddressBookImportExportContactFields::allFields();
     allFields.remove(0);   // drop 'Undefined' field
@@ -59,7 +57,7 @@ static QString contactsToHtml(const KContacts::Addressee::List &contacts)
     }
 
     int counter = 0;
-    content += QLatin1String("<html>\n");
+    QString content = QLatin1String("<html>\n");
     content += QLatin1String(" <body>\n");
     for (const KContacts::Addressee &contact : contacts) {
         const int max = qMax(leftFields.count(), rightFields.count());
@@ -155,4 +153,3 @@ QString MikesStyleFactory::description() const
 {
     return i18n("Mike's Printing Style");
 }
-
