@@ -23,7 +23,6 @@
 
 #include "printstyle.h"
 #include "printingwizard.h"
-#include "helper_p.h"
 
 #include "kaddressbook_debug.h"
 
@@ -35,7 +34,8 @@
 using namespace KABPrinting;
 
 PrintStyle::PrintStyle(PrintingWizard *parent)
-    : QObject(parent), mWizard(parent)
+    : QObject(parent)
+    , mWizard(parent)
 {
     mSortField = KAddressBookImportExport::KAddressBookImportExportContactFields::GivenName;
     mSortOrder = Qt::AscendingOrder;
@@ -96,8 +96,9 @@ void PrintStyle::showPages()
 {
     QWidget *wdg = nullptr;
 
-    Q_FOREACH (wdg, mPageList) {
-        mWizard->setAppropriate(mPageItems[ wdg ], true);
+    for (QWidget *wdg2 : qAsConst(mPageList)) {
+        mWizard->setAppropriate(mPageItems[ wdg2 ], true);
+        wdg = wdg2;
     }
     mWizard->nextButton()->setEnabled(wdg);
     mWizard->finishButton()->setEnabled(!wdg);
@@ -134,4 +135,3 @@ PrintStyleFactory::PrintStyleFactory(PrintingWizard *parent)
 PrintStyleFactory::~PrintStyleFactory()
 {
 }
-
