@@ -31,7 +31,6 @@
 #include <QVBoxLayout>
 
 #include <KComboBox>
-#include <QDialog>
 #include <KLocalizedString>
 
 // helper method to sort contact fields by field label
@@ -53,7 +52,7 @@ StylePage::StylePage(QWidget *parent, const QString &name)
     mSortTypeCombo->addItem(i18nc("@item:inlistbox Ascending sort order", "Ascending"));
     mSortTypeCombo->addItem(i18nc("@item:inlistbox Descending sort order", "Descending"));
 
-    connect(mStyleCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &StylePage::styleChanged);
+    connect(mStyleCombo, QOverload<int>::of(&KComboBox::activated), this, &StylePage::styleChanged);
 }
 
 StylePage::~StylePage()
